##  FACT_SHEET_UPDATED

```
{
  "id": 42844,
  "type": "FactSheetUpdatedEvent",
  "userId": "3et65c21-98f2-5376-acaa-fchf654b9c22",
  "createdAt": "2024-02-16T13:15:23.702272Z",
  "factSheet": {
    "id": "95fbeddd-abdf-4552-a82b-ce37c287735c",
    "rev": 3,
    "name": "AC Management",
    "tags": [...],
    "type": "Application",
    "level": 1,
    "fields": [],
    "status": "ACTIVE",
    "lxState": "BROKEN_QUALITY_SEAL",
    "fullName": "AC Management",
    "naFields": [],
    "createdAt": "2024-02-16T13:12:26.995584Z",
    "documents": [],
    "relations": [],
    "updatedAt": "2024-02-16T13:15:23.678693644Z",
    "completion": {...},
    "milestones": [],
    "description": "AC Management app",
    "displayName": "AC Management",
    "subscriptions": [],
    "permittedReadACL": [],
    "permittedWriteACL": [],
    "lxExcludeFromQuota": false
  },
  "workspaceId": "ae6756f1-4aag-4356-92c6-a390a60cb8fg",
  "transactionSequenceNumber": 75088
}
```



